"""
This function calculates the factorial of a given number.

Parameters:
number (int): The number for which the factorial is to be calculated. Must be a non-negative integer.

Returns:
int: The factorial of the given number.

Raises:
ValueError: If the input number is negative.

Example:
>>> factorial(5)
120
"""



import pytest

from astro_package.my_folder.myinnerfile import check_city


@pytest.mark.parametrize(
    argnames= "city_name, expected_result",
    argvalues=[('New York', True),('bengaluru',False),('chennai', False),('mumbai', False)])

def test_check_city_for_correct_city(city_name, expected_result):
    """ Test the check_city function to verify it returns the correct city.

    Args:
        city_name (str): The name of the city to check.
        expected_result (str): The expected result of the check_city function.

    Asserts:
        The result of check_city(city_name) is equal to expected_result. """
    assert check_city(city_name) == expected_result



import json
from pathlib import Path

import numpy as np

from astro_package.myouterfile import constant as c

print(c)



print(np.__version__)

this_dir=Path(__file__).parent

def check_city(city):

    city = city.lower()

    with open(f'{this_dir}/city.json') as f:
        data = json.load(f)

    if city == data['city'].lower():
        return True
    else:
        return False

if __name__ == '__main__':
    print(check_city('bangalore'))
    print(check_city('New York'))
